Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(641)

Unified Diff: runtime/vm/scanner.h

Issue 10686003: Better breakpoint placement (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/object.cc ('k') | runtime/vm/scanner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/scanner.h
===================================================================
--- runtime/vm/scanner.h (revision 9175)
+++ runtime/vm/scanner.h (working copy)
@@ -64,9 +64,14 @@
// Use CurrentPosition() to extract position.
void ScanTo(intptr_t token_index);
- // Returns token index of first token on or after given line number.
- // Returns negative value if no token exists on or after the line.
- intptr_t TokenIndexAtLine(intptr_t line_number);
+ // Returns index of first and last token on the given line.
+ // Returns both indices < 0 if no token exists on or after the line.
+ // If a token exists after, but not on given line, returns in
+ // *fisrt_token_index the index of the first token after the line,
+ // and a negative value in *last_token_index.
+ void TokenRangeAtLine(intptr_t line_number,
+ intptr_t* first_token_index,
+ intptr_t* last_token_index);
// Scans entire source and returns a stream of tokens.
// Should be called only once.
« no previous file with comments | « runtime/vm/object.cc ('k') | runtime/vm/scanner.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698